@@ -6,7 +6,7 @@
 
 void* initmarkers();
 int	parsemarkerfile(tMarkers* markers,char* filename);
-tInt8 gotomask(tOutput* output,tMarkers* markers,tUInt64* cursorpos);
+tInt8 gotomask(tOutput* output,tMarkers* markers,tUInt64* cursorpos,tInt64 baseaddr);
 
 
 #endif
